:root{
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 161;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

#customize-theme-controls .customize-pane-child.accordion-section-content.customize-widgets-layout__inspector{
  background:#fff;
  box-sizing:border-box;
}
#customize-theme-controls .customize-pane-child.accordion-section-content.customize-widgets-layout__inspector *{
  box-sizing:inherit;
}
#customize-theme-controls .customize-pane-child.accordion-section-content.customize-widgets-layout__inspector .block-editor-block-inspector{
  margin:-12px;
}
#customize-theme-controls .customize-pane-child.accordion-section-content.customize-widgets-layout__inspector .block-editor-block-inspector h3{
  margin-bottom:0;
}

#customize-theme-controls .customize-pane-child.control-section-sidebar.is-sub-section-open{
  transform:translateX(100%);
}

.customize-widgets-header{
  background:#f0f0f1;
  border-bottom:1px solid #e0e0e0;
  display:flex;
  justify-content:flex-end;
  margin:-15px -12px 0;
  z-index:8;
}
@media (min-width:600px){
  .customize-widgets-header{
    margin-bottom:44px;
  }
}
.customize-widgets-header.is-fixed-toolbar-active{
  margin-bottom:0;
}

.customize-widgets-header-toolbar{
  align-items:center;
  border:none;
  display:flex;
  width:100%;
}
.customize-widgets-header-toolbar .customize-widgets-header-toolbar__inserter-toggle.components-button.has-icon{
  border-radius:2px;
  color:#fff;
  height:32px;
  margin:12px auto 12px 0;
  min-width:32px;
  padding:0;
}
.customize-widgets-header-toolbar .customize-widgets-header-toolbar__inserter-toggle.components-button.has-icon:before{
  content:none;
}
@media not (prefers-reduced-motion){
  .customize-widgets-header-toolbar .customize-widgets-header-toolbar__inserter-toggle.components-button.has-icon svg{
    transition:transform .2s cubic-bezier(.165, .84, .44, 1);
  }
}
.customize-widgets-header-toolbar .customize-widgets-header-toolbar__inserter-toggle.components-button.has-icon.is-pressed{
  background:#1e1e1e;
}
.customize-widgets-header-toolbar .customize-widgets-header-toolbar__inserter-toggle.components-button.has-icon.is-pressed svg{
  transform:rotate(-45deg);
}
.customize-widgets-header-toolbar .components-button.has-icon.customize-widgets-editor-history-button.redo-button{
  margin-right:-12px;
}

#customize-sidebar-outer-content{
  min-width:100%;
  width:auto;
}

#customize-outer-theme-controls .widgets-inserter{
  padding:0;
}
#customize-outer-theme-controls .widgets-inserter .customize-section-description-container{
  display:none;
}

.customize-widgets-layout__inserter-panel{
  background:#fff;
}

.customize-widgets-layout__inserter-panel-header{
  align-items:center;
  border-bottom:1px solid #ddd;
  box-sizing:border-box;
  display:flex;
  height:46px;
  justify-content:space-between;
  padding:16px;
}
.customize-widgets-layout__inserter-panel-header .customize-widgets-layout__inserter-panel-header-title{
  margin:0;
}

.block-editor-inserter__quick-inserter .block-editor-inserter__panel-content{
  background:#fff;
}

.customize-widgets-keyboard-shortcut-help-modal__section{
  margin:0 0 2rem;
}
.customize-widgets-keyboard-shortcut-help-modal__section-title{
  font-size:.9rem;
  font-weight:600;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut{
  align-items:baseline;
  border-top:1px solid #ddd;
  display:flex;
  margin-bottom:0;
  padding:.6rem 0;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut:last-child{
  border-bottom:1px solid #ddd;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut:empty{
  display:none;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut-term{
  font-weight:600;
  margin:0 1rem 0 0;
  text-align:left;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut-description{
  flex:1;
  margin:0;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut-key-combination{
  background:none;
  display:block;
  margin:0;
  padding:0;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut-key-combination+.customize-widgets-keyboard-shortcut-help-modal__shortcut-key-combination{
  margin-top:10px;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut-key{
  border-radius:8%;
  margin:0 .2rem;
  padding:.25rem .5rem;
}
.customize-widgets-keyboard-shortcut-help-modal__shortcut-key:last-child{
  margin:0 .2rem 0 0;
}

.components-popover.more-menu-dropdown__content{
  z-index:99998;
}

.customize-control-sidebar_block_editor .block-editor-block-list__block-popover{
  position:fixed !important;
  z-index:7;
}

.customize-control-sidebar_block_editor .components-popover,.customize-widgets-popover .components-popover{
  position:fixed !important;
}

.customize-widgets-welcome-guide__image__wrapper{
  background:#00a0d2;
  margin-bottom:8px;
  text-align:center;
}
.customize-widgets-welcome-guide__image{
  height:auto;
}
.wrap .customize-widgets-welcome-guide__heading{
  font-size:18px;
  font-weight:600;
}
.customize-widgets-welcome-guide__text{
  line-height:1.7;
}
.customize-widgets-welcome-guide__button{
  justify-content:center;
  margin:1em 0;
  width:100%;
}
.customize-widgets-welcome-guide__separator{
  margin:1em 0;
}
.customize-widgets-welcome-guide__more-info{
  line-height:1.4;
}

#customize-theme-controls .customize-pane-child.customize-widgets__sidebar-section{
  background-color:#fff;
  min-height:100%;
  padding-top:12px !important;
}
#customize-theme-controls .customize-pane-child.customize-widgets__sidebar-section.open{
  overflow:unset;
}
#customize-theme-controls .customize-pane-child.customize-widgets__sidebar-section .customize-section-title{
  margin-top:-12px !important;
  position:static !important;
  width:unset !important;
}

.components-modal__screen-overlay{
  z-index:999999;
}

.customize-control-sidebar_block_editor,.customize-widgets-layout__inspector{
  box-sizing:border-box;
}
.customize-control-sidebar_block_editor *,.customize-control-sidebar_block_editor :after,.customize-control-sidebar_block_editor :before,.customize-widgets-layout__inspector *,.customize-widgets-layout__inspector :after,.customize-widgets-layout__inspector :before{
  box-sizing:inherit;
}